@@ -4,7 +4,9 @@
 module Data.Graph.Inductive.Query.MST (
     msTreeAt,msTree,
     -- * Path in MST
-    msPath
+    msPath,
+    -- * Types used
+    LRTree
 ) where
 
 import           Data.Graph.Inductive.Graph
@@ -12,7 +14,7 @@ import qualified Data.Graph.Inductive.Internal.Heap     as H
 import           Data.Graph.Inductive.Internal.RootPath
 
 
-newEdges :: Ord b => LPath b -> Context a b -> [H.Heap b (LPath b)]
+newEdges :: LPath b -> Context a b -> [H.Heap b (LPath b)]
 newEdges (LP p) (_,_,_,s) = map (\(l,v)->H.unit l (LP ((v,l):p))) s
 
 prim :: (Graph gr,Real b) => H.Heap b (LPath b) -> gr a b -> LRTree b
@@ -24,16 +26,16 @@ prim h g =
     where (_,p@(LP ((v,_):_)),h') = H.splitMin h
 
 msTreeAt :: (Graph gr,Real b) => Node -> gr a b -> LRTree b
-msTreeAt v g = prim (H.unit 0 (LP [(v,0)])) g
+msTreeAt v = prim (H.unit 0 (LP [(v,0)]))
 
 msTree :: (Graph gr,Real b) => gr a b -> LRTree b
 msTree g = msTreeAt v g where ((_,v,_,_),_) = matchAny g
 
-msPath :: Real b => LRTree b -> Node -> Node -> Path
+msPath :: LRTree b -> Node -> Node -> Path
 msPath t a b = joinPaths (getLPathNodes a t) (getLPathNodes b t)
 
 joinPaths :: Path -> Path -> Path
-joinPaths p q = joinAt (head p) p q
+joinPaths p = joinAt (head p) p
 
 joinAt :: Node -> Path -> Path -> Path
 joinAt _ (v:vs) (w:ws) | v==w = joinAt v vs ws
